@@ -11,7 +11,8 @@ class APIMetadataService:
         return {
             'version': 'v2',
             'capabilities': await self.capabilities(asgi, request),
-            'catalog': await self.catalog(asgi, request)
+            'catalog': await self.catalog(asgi, request),
+            'client': {'ip': str(request.client.host)}
         }
 
     async def catalog(self, asgi, request) -> dict:
