@@ -14,6 +14,7 @@ from fastapi import APIRouter
 from fastapi import Depends
 from fastapi import Request
 from fastapi.responses import Response
+from fastapi.responses import RedirectResponse
 from fastapi.security import HTTPBearer
 from fastapi.security import HTTPAuthorizationCredentials
 from pydantic import BaseModel
@@ -107,7 +108,7 @@ class ResourceEndpointSetMetaclass(type):
         # instance. This is later used for constructing the appropriate
         # signature. If there is no annotation, assume that it is a string.
         new_class.path_parameter = inspect.Parameter(
-            'path_parameter',
+            new_class.path_parameter,
             inspect.Parameter.POSITIONAL_OR_KEYWORD,
             annotation=hints.get('path_parameter') or str,
             default=new_class.path_parameter
@@ -225,6 +226,17 @@ class ResourceEndpointSet(metaclass=ResourceEndpointSetMetaclass):
     #: The class used to handle IAM.
     iam_class: type = EndpointIAM
 
+    @functools.cached_property
+    def parameters(self) -> typing.List[inspect.Parameter]:
+        """Return the list of path parameters as :class:`inspect.Parameter`
+        instances.
+        """
+        path = []
+        if self.parent_class:
+            path.extend([x.path_parameter for x in self.get_ancestors()])
+        path.append(self.path_parameter)
+        return path
+
     @functools.cached_property
     def qualname(self) -> str:
         """The qualified name of the endpoint, including parent classes."""
@@ -548,7 +560,14 @@ class ResourceEndpointSet(metaclass=ResourceEndpointSetMetaclass):
             raise NotAuthorized
         handler = getattr(self, self.action)
         assert callable(handler), handler #nosec
-        return await handler(*args, **kwargs)
+        return await handler(
+            *args,
+            **(await self.preprocess_params(**kwargs))
+        )
+
+    async def preprocess_params(self, **params) -> dict:
+        """Hook to modify the parameters passed to a request handler."""
+        return params
 
     @classmethod
     async def get_principal(cls,
@@ -585,6 +604,19 @@ class ResourceEndpointSet(metaclass=ResourceEndpointSetMetaclass):
             self, self.request, *args, **kwargs
         )
 
+    def redirect(self,
+        name: str,
+        params: dict,
+        status_code: int = 303
+    ):
+        """Create a redirect response to the given named URL with the
+        given parameters `params`.
+        """
+        return RedirectResponse(
+            self.reverse(name, **params),
+            status_code=status_code
+        )
+
     def reverse(self, name: str, **params) -> str:
         """Reverses the given path relative to the current view."""
         return self.request.url_for(f'{self.qualname}.{name}', **params)
@@ -664,7 +696,21 @@ class ResourceEndpointSet(metaclass=ResourceEndpointSetMetaclass):
         return int(value if str.isdigit(value) else default)
 
     def _get_path_params_from_resource(self, resource) -> dict:
-        return {x.default: resource[x.default] for x in self.path_parameters}
+        if hasattr(resource, 'get_path_parameters'):
+            params = resource.get_path_parameters()
+        elif all([hasattr(resource, x.default) for x in self.path_parameters]):
+            params = {
+                x.default: getattr(resource, x.default)
+                for x in self.path_parameters
+            }
+        elif isinstance(resource, dict):
+            params = {
+                x.default: resource[x.default]
+                for x in self.path_parameters
+            }
+        else:
+            raise TypeError("Unable to determine path parameters.")
+        return params
 
 
 class PublicResourceEndpointSet(ResourceEndpointSet):
